@@ -1,3 +1,4 @@
+# coding: utf-8
 from __future__ import absolute_import
 import os
 
@@ -6,6 +7,7 @@ UTILS_DIR_PATH = os.path.dirname(os.path.abspath(__file__))
 from . import bio_utils
 from . import deep_utils
 from . import generic_utils
+from . import hash_utils
 from . import metric_utils
 from . import model_select_utils
 from . import monitor_utils
@@ -21,8 +23,8 @@ from . import vis_utils
 from .bio_utils import bpHandler
 from .bio_utils import arangeFor_printAlignment
 from .bio_utils import printAlignment
-from .bio_utils import readMonoSeq
-from .bio_utils import readMultiSeq
+from .bio_utils import read_fastseq
+from .bio_utils import kmer_create
 
 from .deep_utils import get_params_size
 from .deep_utils import print_summary
@@ -45,6 +47,10 @@ from .generic_utils import format_spec_create
 from .generic_utils import print_func_create
 from .generic_utils import Table
 
+from .hash_utils import optimize_hash_func
+from .hash_utils import optimize_bit_format
+from .hash_utils import make_hashfuncs
+
 from .metric_utils import norm_vectors
 from .metric_utils import normalize_vectors
 from .metric_utils import mean_squared_error
@@ -97,8 +103,10 @@ from .training_utils import make_batches
 from .training_utils import train_test_split
 from .training_utils import iter_from_variable_len_samples
 
+from .tree_utils import DOTexporterHandler
 from .tree_utils import DecisionTreeDOTexporter
 from .tree_utils import ItemsetTreeDOTexporter
+from .tree_utils import NaiveTrieDOTexporter
 
 from .vis_utils import rgb2hex, rgba2rgb, hex2rgb
 from .vis_utils import chooseTextColor
